-- =============================================
-- SaveToDB Framework for Microsoft SQL Server
-- Version 7.19, March 12, 2018
--
-- This script upgrades SaveToDB Framework 6.x to SaveToDB Framework 7.19
--
-- Copyright 2011-2018 Gartle Technology Corporation
-- =============================================
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.10, 2016-11-02
-- Description: SaveToDB Query List view
-- =============================================

ALTER VIEW [savetodb_dev].[view_query_list]
AS

SELECT
    s.name AS TABLE_SCHEMA
    , o.name AS TABLE_NAME
    , CASE o.[type] WHEN 'U' THEN 'BASE TABLE' WHEN 'V' THEN 'VIEW' WHEN 'P' THEN 'PROCEDURE' WHEN 'IF' THEN 'FUNCTION' ELSE o.type_desc END AS TABLE_TYPE
    , NULL AS TABLE_CODE
    , COALESCE(q.INSERT_PROCEDURE, s.name + '.' + i.name) COLLATE DATABASE_DEFAULT AS INSERT_PROCEDURE
    , COALESCE(q.UPDATE_PROCEDURE, s.name + '.' + u.name) COLLATE DATABASE_DEFAULT AS UPDATE_PROCEDURE
    , COALESCE(q.DELETE_PROCEDURE, s.name + '.' + d.name) COLLATE DATABASE_DEFAULT AS DELETE_PROCEDURE
    , COALESCE(q.PROCEDURE_TYPE, CASE i.[type] WHEN 'P' THEN 'PROCEDURE' ELSE NULL END) AS PROCEDURE_TYPE
FROM
    sys.objects o
    INNER JOIN sys.schemas s ON s.[schema_id] = o.[schema_id]
    LEFT OUTER JOIN sys.procedures i ON i.[schema_id] = o.[schema_id] AND i.name = REPLACE(o.name, '_select', '') + '_insert'
        AND HAS_PERMS_BY_NAME('['+DB_NAME()+'].['+s.name+'].['+i.name+']', 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN sys.procedures u ON u.[schema_id] = o.[schema_id] AND u.name = REPLACE(o.name, '_select', '') + '_update'
        AND HAS_PERMS_BY_NAME('['+DB_NAME()+'].['+s.name+'].['+u.name+']', 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN sys.procedures d ON d.[schema_id] = o.[schema_id] AND d.name = REPLACE(o.name, '_select', '') + '_delete'
        AND HAS_PERMS_BY_NAME('['+DB_NAME()+'].['+s.name+'].['+d.name+']', 'OBJECT', 'EXECUTE') = 1
    LEFT OUTER JOIN [savetodb_dev].[query_list] q ON q.TABLE_SCHEMA = s.name COLLATE DATABASE_DEFAULT AND q.TABLE_NAME = o.name COLLATE DATABASE_DEFAULT
WHERE
    o.[type] IN ('U', 'V', 'P', 'IF')
    AND (HAS_PERMS_BY_NAME(db_name()+'.['+s.name+'].['+o.name+']', 'OBJECT', 'SELECT') = 1
        OR HAS_PERMS_BY_NAME(db_name()+'.['+s.name+'].['+o.name+']', 'OBJECT', 'EXECUTE') = 1)
    AND NOT (s.name = 'dbo' AND (o.name LIKE 'sp_%' OR o.name LIKE 'fn_%' OR o.name LIKE 'sys%'))
    AND NOT s.name IN ('savetodb_etl')
    AND NOT o.name LIKE '%_insert'
    AND NOT o.name LIKE '%_update'
    AND NOT o.name LIKE '%_delete'
    AND NOT o.name LIKE '%_merge'
    AND NOT o.name LIKE '%_change'

UNION ALL
SELECT
    DISTINCT
    q.TABLE_SCHEMA COLLATE DATABASE_DEFAULT AS TABLE_SCHEMA
    , q.TABLE_NAME COLLATE DATABASE_DEFAULT AS TABLE_NAME
    , q.TABLE_TYPE COLLATE DATABASE_DEFAULT AS TABLE_TYPE
    , q.TABLE_CODE
    , q.INSERT_PROCEDURE COLLATE DATABASE_DEFAULT AS INSERT_PROCEDURE
    , q.UPDATE_PROCEDURE COLLATE DATABASE_DEFAULT AS UPDATE_PROCEDURE
    , q.DELETE_PROCEDURE COLLATE DATABASE_DEFAULT AS DELETE_PROCEDURE
    , q.PROCEDURE_TYPE
FROM
    [savetodb_dev].[query_list] q
    LEFT OUTER JOIN sys.schemas s ON s.name = q.TABLE_SCHEMA COLLATE DATABASE_DEFAULT
    LEFT OUTER JOIN sys.objects t ON t.[schema_id] = s.[schema_id] AND t.name = q.TABLE_NAME COLLATE DATABASE_DEFAULT
WHERE
    q.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND t.[object_id] IS NULL

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.9, 2016-06-21
-- Description: SaveToDB Query List view
--
-- This view can be used as a data source of other Query List views
-- which can filter different logic areas of a database.
-- =============================================

ALTER VIEW [savetodb_xls].[view_query_list]
AS

SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TABLE_TYPE
    , t.TABLE_CODE
    , t.INSERT_PROCEDURE
    , t.UPDATE_PROCEDURE
    , t.DELETE_PROCEDURE
    , t.PROCEDURE_TYPE
FROM
    [savetodb_dev].[view_query_list] t
WHERE
    NOT t.TABLE_SCHEMA IN ('etl01', 'dbo01', 'xls01', 'savetodb_dev', 'savetodb_xls', 'SAVETODB_DEV', 'SAVETODB_XLS')
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI IN (
          'viewColumnTranslation'
        , 'viewObjectTranslation'
        , 'viewEventHandlers'
        , 'viewParameterValues'
        , 'viewTableFormats'
        , 'view_column_translation'
        , 'view_object_translation'
        , 'view_event_handlers'
        , 'view_parameter_values'
        , 'view_table_formats'
        )
    AND NOT t.TABLE_NAME LIKE 'viewQueryList%'
    AND NOT t.TABLE_NAME LIKE 'viewParameterValues%'
    AND NOT t.TABLE_NAME LIKE 'viewValidationList%'
    AND NOT t.TABLE_NAME LIKE 'uspExcelEvent%'
    AND NOT t.TABLE_NAME LIKE 'uspParameterValues%'
    AND NOT t.TABLE_NAME LIKE 'uspValidationList%'
    AND NOT t.TABLE_NAME LIKE 'ufnExcelEvent%'
    AND NOT t.TABLE_NAME LIKE 'ufnParameterValues%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'view_query_list%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'xl_%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'view_xl_%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'usp_xl_%'
    AND NOT t.TABLE_NAME COLLATE SQL_Latin1_General_CP1_CI_AI LIKE 'ufn_xl_%'

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.9, 2016-06-21
-- Description: Object descriptions for users
-- =============================================

ALTER VIEW [savetodb_xls].[view_object_description]
AS

SELECT
    t.ID
    , t.LANGUAGE_NAME
    , t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.TRANSLATED_NAME
    , t.TRANSLATED_COMMENT
FROM
    [savetodb_xls].[view_query_list] q
    INNER JOIN [savetodb_dev].[object_translation] t ON t.TABLE_SCHEMA = q.TABLE_SCHEMA AND t.TABLE_NAME = q.TABLE_NAME
WHERE
    t.TRANSLATED_NAME IS NOT NULL
    AND t.TRANSLATED_COMMENT IS NOT NULL

GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.9, 2015-06-13
-- Description: The procedure updates Excel table formats
-- =============================================

ALTER PROCEDURE [savetodb_dev].[usp_update_table_format]
    @Schema nvarchar(128) = NULL
    , @Name nvarchar(128) = NULL
    , @ExcelFormatXML xml = NULL
AS
BEGIN

SET NOCOUNT ON

IF @Schema IS NOT NULL AND @Name IS NOT NULL
    IF @ExcelFormatXML IS NULL
        BEGIN

        DELETE [savetodb_dev].[table_formats]
        WHERE
            TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name

        END
    ELSE
        BEGIN

        UPDATE [savetodb_dev].[table_formats]
        SET
            TABLE_EXCEL_FORMAT_XML = @ExcelFormatXML
        WHERE
            TABLE_SCHEMA = @Schema AND TABLE_NAME = @Name

        IF @@ROWCOUNT = 0
            INSERT [savetodb_dev].[table_formats]
                (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML)
            VALUES
                (@Schema, @Name, @ExcelFormatXML)

        END
                
END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts column translation for new objects
-- =============================================

ALTER PROCEDURE [savetodb_etl].[usp_update_column_translation]
    @schema nvarchar(128) = NULL
    , @language_name char(2) = NULL
AS
BEGIN

IF @language_name IS NULL
    BEGIN
    SELECT 'Specify @language_name parameter' AS [message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[column_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , t.COLUMN_NAME
    , @language_name AS LANGUAGE_NAME
    , t.COLUMN_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
    SELECT
        t.TABLE_SCHEMA
        , t.TABLE_NAME
        , t.TABLE_TYPE
        , c.COLUMN_NAME
        , c.ORDINAL_POSITION
    FROM
        INFORMATION_SCHEMA.COLUMNS c
        INNER JOIN INFORMATION_SCHEMA.TABLES t
            ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
    WHERE
        (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')  -- User tables and views only
        AND t.TABLE_SCHEMA = COALESCE(@schema, t.TABLE_SCHEMA)
        AND NOT t.TABLE_NAME IN (
            'object_translation'
            , 'column_translation'
            , 'parameter_values'
            , 'event_handlers'
            , 'table_formats'
            , 'query_list'

            , 'view_query_list'
            , 'view_event_handlers'
            , 'view_column_translation'
            , 'view_object_translation'
            , 'view_parameter_values'
            , 'view_table_formats'
            , 'view_object_translation_suggest'
            , 'view_event_handlers_suggest'
            , 'view_object_description'

            , 'usp_update_table_format'
            , 'usp_generate_edit_procedures'
            , 'usp_update_column_translation'
            , 'usp_update_column_translation_group'
            , 'usp_update_object_translation'
            , 'usp_update_object_translation_absent'
            , 'usp_update_event_handlers'
            )
        AND NOT t.TABLE_NAME LIKE 'view_parameter_values_%'
        AND NOT t.TABLE_NAME LIKE 'view_validation_list_%'
        AND NOT t.TABLE_NAME LIKE 'view_xl_%'
        AND NOT t.TABLE_NAME LIKE 'xl_%'
        AND NOT t.TABLE_SCHEMA LIKE 'etl%'

    UNION ALL
        
    SELECT
        p.ROUTINE_SCHEMA AS TABLE_SCHEMA
        , p.ROUTINE_NAME AS TABLE_NAME
        , p.ROUTINE_TYPE AS TABLE_TYPE
        , REPLACE(c.PARAMETER_NAME, '@', '') AS COLUMN_NAME
        , c.ORDINAL_POSITION
    FROM
        INFORMATION_SCHEMA.PARAMETERS c
        INNER JOIN INFORMATION_SCHEMA.ROUTINES p
            ON p.SPECIFIC_SCHEMA = c.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = c.SPECIFIC_NAME
    WHERE
        p.ROUTINE_TYPE = 'PROCEDURE'
        AND p.ROUTINE_SCHEMA = COALESCE(@schema, p.ROUTINE_SCHEMA)
        AND NOT p.ROUTINE_NAME LIKE 'sp_%'                      -- System procedures 
        AND c.PARAMETER_MODE LIKE 'IN%'                         -- Input parameters only
        AND NOT p.ROUTINE_SCHEMA LIKE 'etl%'                    -- Service schema
        AND NOT p.ROUTINE_NAME LIKE 'usp%_insert'               -- Hidden procedures for INSERT
        AND NOT p.ROUTINE_NAME LIKE 'usp%_update'               -- Hidden procedures for UPDATE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_delete'               -- Hidden procedures for DELETE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_merge'                -- Hidden procedures for MERGE
        AND NOT p.ROUTINE_NAME LIKE 'usp%_change'               -- Hidden procedures used as CHANGE event handlers
        AND NOT p.ROUTINE_NAME LIKE 'usp_excel_event_%'         -- Hidden procedures for Excel Event Handling
        AND NOT p.ROUTINE_NAME LIKE 'usp_parameter_values%'     -- Service procedures for parameter values
        AND NOT p.ROUTINE_NAME LIKE 'usp_validation_List%'      -- Service procedures for validation lists
        AND NOT p.ROUTINE_NAME = 'usp_generate_edit_procedures' -- Service procedure for edit procedure generation
        AND NOT p.ROUTINE_NAME LIKE 'usp_update_translation_%'  -- Service procedures for translation
    ) t

    LEFT OUTER JOIN [savetodb_dev].[column_translation] o
        ON o.TABLE_SCHEMA = t.TABLE_SCHEMA COLLATE DATABASE_DEFAULT AND o.TABLE_NAME = t.TABLE_NAME COLLATE DATABASE_DEFAULT
            AND o.COLUMN_NAME = t.COLUMN_NAME COLLATE DATABASE_DEFAULT
            AND o.LANGUAGE_NAME = @language_name
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts column translation for new columns and parameters
-- =============================================

ALTER PROCEDURE [savetodb_etl].[usp_update_column_translation_group]
    @schema nvarchar(128) = NULL
    , @language_name char(2) = NULL
AS
BEGIN

IF @language_name IS NULL
    BEGIN
    SELECT 'Specify @language_name parameter' AS [message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[column_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , COLUMN_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , NULL AS TABLE_NAME
    , t.COLUMN_NAME
    , @language_name AS LANGUAGE_NAME
    , t.COLUMN_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (
        SELECT
            t.TABLE_SCHEMA
            , t.COLUMN_NAME
        FROM
            (   
                SELECT
                    t.TABLE_SCHEMA
                    , t.TABLE_NAME
                    , t.TABLE_TYPE
                    , c.COLUMN_NAME
                    , c.ORDINAL_POSITION
                FROM
                    INFORMATION_SCHEMA.COLUMNS c
                    INNER JOIN INFORMATION_SCHEMA.TABLES t
                        ON t.TABLE_SCHEMA = c.TABLE_SCHEMA AND t.TABLE_NAME = c.TABLE_NAME
                WHERE
                    (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')  -- User tables and views only
                    AND t.TABLE_SCHEMA = COALESCE(@schema, t.TABLE_SCHEMA)
                    AND NOT t.TABLE_NAME IN (
                        'object_translation'
                        , 'column_translation'
                        , 'parameter_values'
                        , 'event_handlers'
                        , 'table_formats'
                        , 'query_list'

                        , 'view_query_list'
                        , 'view_event_handlers'
                        , 'view_column_translation'
                        , 'view_object_translation'
                        , 'view_parameter_values'
                        , 'view_table_formats'
                        , 'view_object_translation_suggest'
                        , 'view_event_handlers_suggest'
                        , 'view_object_description'

                        , 'usp_update_table_format'
                        , 'usp_generate_edit_procedures'
                        , 'usp_update_column_translation'
                        , 'usp_update_column_translation_group'
                        , 'usp_update_object_translation'
                        , 'usp_update_object_translation_absent'
                        , 'usp_update_event_handlers'
                        )
                    AND NOT t.TABLE_NAME LIKE 'view_parameter_values_%'
                    AND NOT t.TABLE_NAME LIKE 'view_validation_list_%'
                    AND NOT t.TABLE_NAME LIKE 'view_xl_%'
                    AND NOT t.TABLE_NAME LIKE 'xl_%'
                    AND NOT t.TABLE_SCHEMA LIKE 'etl%'

                UNION ALL
            
                SELECT
                    p.ROUTINE_SCHEMA AS TABLE_SCHEMA
                    , p.ROUTINE_NAME AS TABLE_NAME
                    , p.ROUTINE_TYPE AS TABLE_TYPE
                    , REPLACE(c.PARAMETER_NAME, '@', '') AS COLUMN_NAME
                    , c.ORDINAL_POSITION
                FROM
                    INFORMATION_SCHEMA.PARAMETERS c
                    INNER JOIN INFORMATION_SCHEMA.ROUTINES p
                        ON p.SPECIFIC_SCHEMA = c.SPECIFIC_SCHEMA AND p.SPECIFIC_NAME = c.SPECIFIC_NAME
                WHERE
                    p.ROUTINE_TYPE = 'PROCEDURE'
                    AND p.ROUTINE_SCHEMA = COALESCE(@schema, p.ROUTINE_SCHEMA)
                    AND NOT p.ROUTINE_NAME LIKE 'sp_%'                      -- System procedures 
                    AND c.PARAMETER_MODE LIKE 'IN%'                         -- Input parameters only
                    AND NOT p.ROUTINE_SCHEMA LIKE 'etl%'                    -- Service schema
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_insert'               -- Hidden procedures for INSERT
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_update'               -- Hidden procedures for UPDATE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_delete'               -- Hidden procedures for DELETE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_merge'                -- Hidden procedures for MERGE
                    AND NOT p.ROUTINE_NAME LIKE 'usp%_change'               -- Hidden procedures used as CHANGE event handlers
                    AND NOT p.ROUTINE_NAME LIKE 'usp_excel_event_%'         -- Hidden procedures for Excel Event Handling
                    AND NOT p.ROUTINE_NAME LIKE 'usp_parameter_values%'     -- Service procedures for parameter values
                    AND NOT p.ROUTINE_NAME LIKE 'usp_validation_List%'      -- Service procedures for validation lists
                    AND NOT p.ROUTINE_NAME = 'usp_generate_edit_procedures' -- Service procedure for edit procedure generation
                    AND NOT p.ROUTINE_NAME LIKE 'usp_update_translation_%'  -- Service procedures for translation
            ) t
        GROUP BY
            t.TABLE_SCHEMA
            , t.COLUMN_NAME
    ) t
    LEFT OUTER JOIN [savetodb_dev].[column_translation] o
        ON UPPER(o.TABLE_SCHEMA) = UPPER(t.TABLE_SCHEMA) COLLATE DATABASE_DEFAULT AND o.TABLE_NAME IS NULL
            AND UPPER(o.COLUMN_NAME) = UPPER(t.COLUMN_NAME) COLLATE DATABASE_DEFAULT
            AND UPPER(o.LANGUAGE_NAME) = UPPER(@language_name)
WHERE
    o.COLUMN_NAME IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts translation for new objects
-- =============================================

ALTER PROCEDURE [savetodb_etl].[usp_update_object_translation]
    @schema nvarchar(128) = NULL
    , @language_name char(2) = NULL
AS
BEGIN

IF @language_name IS NULL
    BEGIN
    SELECT 'Specify @language_name parameter' AS [message]
    RETURN
    END

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[object_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , @language_name AS LANGUAGE_NAME
    , t.TABLE_SCHEMA + '.' + t.TABLE_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            (t.TABLE_TYPE = 'BASE TABLE' OR t.TABLE_TYPE = 'VIEW')
            AND t.TABLE_SCHEMA = COALESCE(@schema, t.TABLE_SCHEMA)
            AND NOT (
                t.TABLE_NAME LIKE 'view_parameter_values_%'
                OR t.TABLE_NAME LIKE 'view_validation_list_%'
                OR t.TABLE_NAME LIKE 'view_xl_%'
                OR t.TABLE_NAME LIKE 'xl_%'
            )

        UNION ALL
        
        SELECT
            p.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , p.ROUTINE_NAME AS TABLE_NAME
            , p.ROUTINE_TYPE AS TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.ROUTINES p
        WHERE
            p.ROUTINE_TYPE = 'PROCEDURE'
            AND p.ROUTINE_SCHEMA = COALESCE(@schema, p.ROUTINE_SCHEMA)
            AND NOT (
                p.ROUTINE_NAME LIKE 'usp_parameter_values_%'
                OR p.ROUTINE_NAME LIKE 'usp_excel_event_%'
                OR p.ROUTINE_NAME LIKE 'usp_validation_list_%'
                OR p.ROUTINE_NAME LIKE 'usp_xl_%'
                OR p.ROUTINE_NAME LIKE 'xl_%'
            )
    ) t
    LEFT OUTER JOIN [savetodb_dev].[object_translation] o
        ON UPPER(o.TABLE_SCHEMA) = UPPER(t.TABLE_SCHEMA) COLLATE DATABASE_DEFAULT AND UPPER(o.TABLE_NAME) = UPPER(t.TABLE_NAME) COLLATE DATABASE_DEFAULT
            AND UPPER(o.LANGUAGE_NAME) = UPPER(@language_name)
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     6.8, 2016-05-27
-- Description: The procedure inserts translation of existing languages for absent objects
-- =============================================

ALTER PROCEDURE [savetodb_etl].[usp_update_object_translation_absent]
AS
BEGIN

SET NOCOUNT ON

INSERT INTO [savetodb_dev].[object_translation]
    (
    TABLE_SCHEMA
    , TABLE_NAME
    , LANGUAGE_NAME
    , TRANSLATED_NAME
    , TRANSLATED_DESC
    )
SELECT
    t.TABLE_SCHEMA
    , t.TABLE_NAME
    , l.LANGUAGE_NAME
    , t.TABLE_SCHEMA + '.' + t.TABLE_NAME AS TRANSLATED_NAME
    , NULL AS TRANSLATED_DESC
FROM
    (   
        SELECT
            t.TABLE_SCHEMA
            , t.TABLE_NAME
            , t.TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.TABLES t
        WHERE
            (t.TABLE_TYPE = 'BASE TABLE'
            OR t.TABLE_TYPE = 'VIEW')
            AND NOT (
                t.TABLE_NAME LIKE 'view_parameter_values_%'
                OR t.TABLE_NAME LIKE 'view_validation_list_%'
                OR t.TABLE_NAME LIKE 'view_xl_%'
                OR t.TABLE_NAME LIKE 'xl_%'
            )

        UNION ALL
        
        SELECT
            p.ROUTINE_SCHEMA AS TABLE_SCHEMA
            , p.ROUTINE_NAME AS TABLE_NAME
            , p.ROUTINE_TYPE AS TABLE_TYPE
        FROM
            INFORMATION_SCHEMA.ROUTINES p
        WHERE
            p.ROUTINE_TYPE = 'PROCEDURE'
            AND NOT (
                p.ROUTINE_NAME LIKE 'usp_parameter_values_%'
                OR p.ROUTINE_NAME LIKE 'usp_excel_event_%'
                OR p.ROUTINE_NAME LIKE 'usp_validation_list_%'
                OR p.ROUTINE_NAME LIKE 'usp_xl_%'
                OR p.ROUTINE_NAME LIKE 'xl_%'
            )
    ) t
    INNER JOIN (
        SELECT
            DISTINCT
            TABLE_SCHEMA
            , LANGUAGE_NAME
        FROM
            [savetodb_dev].[object_translation]
    ) l ON l.TABLE_SCHEMA = t.TABLE_SCHEMA COLLATE DATABASE_DEFAULT
    LEFT OUTER JOIN [savetodb_dev].[object_translation] o
        ON o.TABLE_SCHEMA = t.TABLE_SCHEMA COLLATE DATABASE_DEFAULT AND o.TABLE_NAME = t.TABLE_NAME COLLATE DATABASE_DEFAULT
            AND o.LANGUAGE_NAME = l.LANGUAGE_NAME
WHERE
    o.TABLE_SCHEMA IS NULL

SELECT LTRIM(STR(@@ROWCOUNT)) + ' rows inserted' AS [message]

END
GO

DELETE FROM [savetodb_dev].[table_formats] WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'event_handlers';
GO

INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'event_handlers', '<table name="savetodb_dev.event_handlers"><columnFormats><column name="" property="ListObjectName" value="event_handlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="18.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$7" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the varchar(50) datatype." type="String"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$7" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="57.57" type="Double"/><column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$7" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$7" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="45" type="Double"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$7" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$7" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$446,$G$7:$G$446,$I$7:$I$446" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="EVENT_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="MENU_ORDER" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="SortFields(5)" property="KeyfieldName" value="HANDLER_NAME" type="String"/><column name="SortFields(5)" property="SortOn" value="0" type="Double"/><column name="SortFields(5)" property="Order" value="1" type="Double"/><column name="SortFields(5)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO

-- 7.19

DELETE FROM [savetodb_dev].[table_formats] WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'event_handlers';
GO
DELETE FROM [savetodb_dev].[table_formats] WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'parameter_values';
GO

INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'event_handlers', '<table name="savetodb_dev.event_handlers"><columnFormats><column name="" property="ListObjectName" value="event_handlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="_RowNum" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="VerticalAlignment" value="-4160" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="21.71" type="Double"/><column name="TABLE_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$7" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="18.57" type="Double"/><column name="COLUMN_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$7" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="EVENT_NAME" property="Validation.ErrorMessage" value="The column requires values of the varchar(50) datatype." type="String"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$7" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$7" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="57.57" type="Double"/><column name="HANDLER_NAME" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$7" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="VerticalAlignment" value="-4160" type="Double"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$7" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="45" type="Double"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$7" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="VerticalAlignment" value="-4160" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$7" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="VerticalAlignment" value="-4160" type="Double"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$7" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="VerticalAlignment" value="-4160" type="Double"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$7" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="VerticalAlignment" value="-4160" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$446" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).AppliesTo.Address" value="$E$7:$E$446,$G$7:$G$446,$I$7:$I$446" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Priority" value="3" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Formula1" value="=ISBLANK(E7)" type="String"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_NAME" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SortFields(1)" property="KeyfieldName" value="TABLE_SCHEMA" type="String"/><column name="SortFields(1)" property="SortOn" value="0" type="Double"/><column name="SortFields(1)" property="Order" value="1" type="Double"/><column name="SortFields(1)" property="DataOption" value="0" type="Double"/><column name="SortFields(2)" property="KeyfieldName" value="TABLE_NAME" type="String"/><column name="SortFields(2)" property="SortOn" value="0" type="Double"/><column name="SortFields(2)" property="Order" value="1" type="Double"/><column name="SortFields(2)" property="DataOption" value="0" type="Double"/><column name="SortFields(3)" property="KeyfieldName" value="EVENT_NAME" type="String"/><column name="SortFields(3)" property="SortOn" value="0" type="Double"/><column name="SortFields(3)" property="Order" value="1" type="Double"/><column name="SortFields(3)" property="DataOption" value="0" type="Double"/><column name="SortFields(4)" property="KeyfieldName" value="MENU_ORDER" type="String"/><column name="SortFields(4)" property="SortOn" value="0" type="Double"/><column name="SortFields(4)" property="Order" value="1" type="Double"/><column name="SortFields(4)" property="DataOption" value="0" type="Double"/><column name="SortFields(5)" property="KeyfieldName" value="HANDLER_NAME" type="String"/><column name="SortFields(5)" property="SortOn" value="0" type="Double"/><column name="SortFields(5)" property="Order" value="1" type="Double"/><column name="SortFields(5)" property="DataOption" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO
INSERT INTO [savetodb_dev].[table_formats] ([TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML]) VALUES (N'savetodb_dev', N'parameter_values', '<table name="savetodb_dev.parameter_values"><columnFormats><column name="" property="ListObjectName" value="parameter_values_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$7" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$7" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$7" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$7" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="26.29" type="Double"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="PARAMETER_NAME" property="Address" value="$F$7" type="String"/><column name="PARAMETER_NAME" property="ColumnWidth" value="20.29" type="Double"/><column name="PARAMETER_NAME" property="Validation.Type" value="6" type="Double"/><column name="PARAMETER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="PARAMETER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="PARAMETER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="PARAMETER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="PARAMETER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="PARAMETER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="PARAMETER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_SCHEMA" property="Address" value="$G$7" type="String"/><column name="SELECT_SCHEMA" property="ColumnWidth" value="17.29" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="SELECT_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_NAME" property="Address" value="$H$7" type="String"/><column name="SELECT_NAME" property="ColumnWidth" value="34.86" type="Double"/><column name="SELECT_NAME" property="Validation.Type" value="6" type="Double"/><column name="SELECT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_NAME" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_NAME" property="Validation.Formula1" value="128" type="String"/><column name="SELECT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_TYPE" property="Address" value="$I$7" type="String"/><column name="SELECT_TYPE" property="ColumnWidth" value="13.86" type="Double"/><column name="SELECT_TYPE" property="Validation.Type" value="3" type="Double"/><column name="SELECT_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="SELECT_TYPE" property="Validation.Operator" value="8" type="Double"/><column name="SELECT_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;VALUES;RANGE" type="String"/><column name="SELECT_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="SELECT_TYPE" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="SELECT_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="SELECT_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="SELECT_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="SELECT_CODE" property="Address" value="$J$7" type="String"/><column name="SELECT_CODE" property="ColumnWidth" value="70.71" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).AppliesTo.Address" value="$D$7:$D$63" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Priority" value="7" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Formula1" value="=ISBLANK(D7)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(2).Interior.PatternThemeColor" value="-1" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$G$7:$G$63,$I$7:$I$63" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Priority" value="4" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(G7)" type="String"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="SELECT_SCHEMA" property="FormatConditions(1).Interior.PatternThemeColor" value="-1" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/></columnFormats></table>');
GO

ALTER TABLE [savetodb_dev].[event_handlers] ALTER COLUMN [HANDLER_NAME] nvarchar(128) NULL;
GO

UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList' WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'event_handlers'         AND [COLUMN_NAME] = N'EVENT_NAME'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                   WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'event_handlers'         AND [COLUMN_NAME] = N'HANDLER_TYPE'     AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                        WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'parameter_values'       AND [COLUMN_NAME] = N'SELECT_TYPE'      AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                         WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'query_list'             AND [COLUMN_NAME] = N'TABLE_TYPE'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                  WHERE [TABLE_SCHEMA] = N'savetodb_dev' AND [TABLE_NAME] = N'query_list'             AND [COLUMN_NAME] = N'PROCEDURE_TYPE'   AND [EVENT_NAME] = N'ValidationList';

UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList' WHERE [TABLE_SCHEMA] = N'savetodb_xls' AND [TABLE_NAME] = N'view_event_handlers'     AND [COLUMN_NAME] = N'EVENT_NAME'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                   WHERE [TABLE_SCHEMA] = N'savetodb_xls' AND [TABLE_NAME] = N'view_event_handlers'     AND [COLUMN_NAME] = N'HANDLER_TYPE'     AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                        WHERE [TABLE_SCHEMA] = N'savetodb_xls' AND [TABLE_NAME] = N'view_parameter_values'   AND [COLUMN_NAME] = N'SELECT_TYPE'      AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                         WHERE [TABLE_SCHEMA] = N'savetodb_xls' AND [TABLE_NAME] = N'view_query_list'         AND [COLUMN_NAME] = N'TABLE_TYPE'       AND [EVENT_NAME] = N'ValidationList';
UPDATE [savetodb_dev].[event_handlers] SET [HANDLER_TYPE] = N'VALUES', [HANDLER_CODE] = N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                  WHERE [TABLE_SCHEMA] = N'savetodb_xls' AND [TABLE_NAME] = N'view_query_list'         AND [COLUMN_NAME] = N'PROCEDURE_TYPE'   AND [EVENT_NAME] = N'ValidationList';

INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_dev' AS [TABLE_SCHEMA], N'event_handlers'          AS [TABLE_NAME], N'HANDLER_CODE'    AS [COLUMN_NAME], N'DoNotConvertFormulas' AS [EVENT_NAME], NULL AS [HANDLER_TYPE], NULL AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_xls' AS [TABLE_SCHEMA], N'view_event_handlers'      AS [TABLE_NAME], N'HANDLER_CODE'    AS [COLUMN_NAME], N'DoNotConvertFormulas' AS [EVENT_NAME], NULL AS [HANDLER_TYPE], NULL AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;

INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_dev' AS [TABLE_SCHEMA], N'event_handlers'          AS [TABLE_NAME], N'EVENT_NAME'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList'    AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_dev' AS [TABLE_SCHEMA], N'event_handlers'          AS [TABLE_NAME], N'HANDLER_TYPE'    AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                      AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_dev' AS [TABLE_SCHEMA], N'parameter_values'        AS [TABLE_NAME], N'SELECT_TYPE'     AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                           AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_dev' AS [TABLE_SCHEMA], N'query_list'              AS [TABLE_NAME], N'TABLE_TYPE'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                            AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_dev' AS [TABLE_SCHEMA], N'query_list'              AS [TABLE_NAME], N'PROCEDURE_TYPE'  AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                     AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;

INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_xls' AS [TABLE_SCHEMA], N'view_event_handlers'      AS [TABLE_NAME], N'EVENT_NAME'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'Actions,Change,ContextMenu,DoubleClick,SelectionChange,ConvertFormulas,DoNotConvertFormulas,DoNotSelect,DoNotSave,DoNotChange,ProtectRows,Formula,FormulaValue,ValidationList,SelectionList'    AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_xls' AS [TABLE_SCHEMA], N'view_event_handlers'      AS [TABLE_NAME], N'HANDLER_TYPE'    AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,TEXT,MACRO,CMD,VALUES,RANGE,REFRESH,MENUSEPARATOR'                                                                                                      AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_xls' AS [TABLE_SCHEMA], N'view_parameter_values'    AS [TABLE_NAME], N'SELECT_TYPE'     AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,FUNCTION,CODE,HTTP,VALUES,RANGE'                                                                                                                                           AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_xls' AS [TABLE_SCHEMA], N'view_query_list'          AS [TABLE_NAME], N'TABLE_TYPE'      AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,VIEW,PROCEDURE,CODE,HTTP,TEXT'                                                                                                                                                            AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
INSERT INTO [savetodb_dev].[event_handlers] ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_TYPE], [HANDLER_CODE]) SELECT s.[TABLE_SCHEMA], s.[TABLE_NAME], s.[COLUMN_NAME], s.[EVENT_NAME], s.[HANDLER_TYPE], s.[HANDLER_CODE] FROM (SELECT N'savetodb_xls' AS [TABLE_SCHEMA], N'view_query_list'          AS [TABLE_NAME], N'PROCEDURE_TYPE'  AS [COLUMN_NAME], N'ValidationList' AS [EVENT_NAME], N'VALUES' AS [HANDLER_TYPE], N'TABLE,PROCEDURE,CODE,MERGE'                                                                                                                                                                     AS [HANDLER_CODE]) s LEFT OUTER JOIN [savetodb_dev].[event_handlers] t ON t.[TABLE_SCHEMA] = s.[TABLE_SCHEMA] AND t.[TABLE_NAME] = s.[TABLE_NAME] AND t.[COLUMN_NAME] = s.[COLUMN_NAME] AND t.[EVENT_NAME] = s.[EVENT_NAME] WHERE t.[TABLE_NAME] IS NULL;
GO
