-- =============================================
-- Application: Sample 11 - 11 Steps for Advanced Users
-- Version 10.8, January 9, 2023
--
-- Copyright 2019-2023 Sergey Vaselenko
--
-- License: MIT
-- =============================================

SET NOCOUNT ON
GO

CREATE SCHEMA [s11];
GO

CREATE TABLE [s11].[Companies] (
      [Company] nvarchar(255) NOT NULL
    , [LastModified] datetime NULL
    , [UserName] nvarchar(50) NULL
    , CONSTRAINT [PK_Companies] PRIMARY KEY ([Company])
);
GO

CREATE TABLE [s11].[formats] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [TABLE_SCHEMA] nvarchar(128) NOT NULL
    , [TABLE_NAME] nvarchar(128) NOT NULL
    , [TABLE_EXCEL_FORMAT_XML] xml NULL
    , [APP] nvarchar(50) NULL
    , CONSTRAINT [PK_formats] PRIMARY KEY ([ID])
    , CONSTRAINT [IX_formats] UNIQUE ([TABLE_NAME], [TABLE_SCHEMA], [APP])
);
GO

CREATE TABLE [s11].[handlers] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [TABLE_SCHEMA] nvarchar(20) NULL
    , [TABLE_NAME] nvarchar(128) NOT NULL
    , [COLUMN_NAME] nvarchar(128) NULL
    , [EVENT_NAME] varchar(25) NULL
    , [HANDLER_SCHEMA] nvarchar(20) NULL
    , [HANDLER_NAME] nvarchar(128) NULL
    , [HANDLER_TYPE] varchar(25) NULL
    , [HANDLER_CODE] nvarchar(max) NULL
    , [TARGET_WORKSHEET] nvarchar(128) NULL
    , [MENU_ORDER] int NULL
    , [EDIT_PARAMETERS] bit NULL
    , CONSTRAINT [PK_handlers] PRIMARY KEY ([ID])
    , CONSTRAINT [IX_handlers] UNIQUE ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME])
);
GO

CREATE TABLE [s11].[Payments] (
      [ID] int IDENTITY(1,1) NOT NULL
    , [Date] datetime NULL
    , [Amount] float NULL
    , [Account] nvarchar(255) NULL
    , [Item] nvarchar(255) NULL
    , [Company] nvarchar(255) NULL
    , [Comment] nvarchar(255) NULL
    , CONSTRAINT [PK_Payments] PRIMARY KEY ([ID])
);
GO

INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Corporate Income Tax', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Customer C1', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Customer C2', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Customer C3', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Individual Income Tax', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Payroll Taxes', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Supplier S1', NULL, NULL);
INSERT INTO [s11].[Companies] ([Company], [LastModified], [UserName]) VALUES (N'Supplier S2', NULL, NULL);
GO

SET IDENTITY_INSERT [s11].[formats] ON;
INSERT INTO [s11].[formats] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML], [APP]) VALUES (1, N's11', N'handlers', N'<table name="s11.handlers"><columnFormats><column name="" property="ListObjectName" value="handlers_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="ID" property="Validation.Type" value="1" type="Double"/><column name="ID" property="Validation.Operator" value="1" type="Double"/><column name="ID" property="Validation.Formula1" value="-2147483648" type="String"/><column name="ID" property="Validation.Formula2" value="2147483647" type="String"/><column name="ID" property="Validation.AlertStyle" value="1" type="Double"/><column name="ID" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="ID" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="ID" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="ID" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="ID" property="Validation.ShowInput" value="True" type="Boolean"/><column name="ID" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_SCHEMA" property="Address" value="$D$4" type="String"/><column name="TABLE_SCHEMA" property="ColumnWidth" value="16.57" type="Double"/><column name="TABLE_SCHEMA" property="NumberFormat" value="General" type="String"/><column name="TABLE_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="TABLE_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TABLE_NAME" property="Address" value="$E$4" type="String"/><column name="TABLE_NAME" property="ColumnWidth" value="14.43" type="Double"/><column name="TABLE_NAME" property="NumberFormat" value="General" type="String"/><column name="TABLE_NAME" property="Validation.Type" value="6" type="Double"/><column name="TABLE_NAME" property="Validation.Operator" value="8" type="Double"/><column name="TABLE_NAME" property="Validation.Formula1" value="128" type="String"/><column name="TABLE_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="TABLE_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TABLE_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TABLE_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TABLE_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="COLUMN_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="COLUMN_NAME" property="Address" value="$F$4" type="String"/><column name="COLUMN_NAME" property="ColumnWidth" value="17.43" type="Double"/><column name="COLUMN_NAME" property="NumberFormat" value="General" type="String"/><column name="COLUMN_NAME" property="Validation.Type" value="6" type="Double"/><column name="COLUMN_NAME" property="Validation.Operator" value="8" type="Double"/><column name="COLUMN_NAME" property="Validation.Formula1" value="128" type="String"/><column name="COLUMN_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="COLUMN_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="COLUMN_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="COLUMN_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="COLUMN_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="EVENT_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EVENT_NAME" property="Address" value="$G$4" type="String"/><column name="EVENT_NAME" property="ColumnWidth" value="15" type="Double"/><column name="EVENT_NAME" property="NumberFormat" value="General" type="String"/><column name="EVENT_NAME" property="Validation.Type" value="3" type="Double"/><column name="EVENT_NAME" property="Validation.Operator" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.Formula1" value="Actions;Change;ContextMenu;DoubleClick;SelectionChange;ConvertFormulas;DoNotConvertFormulas;DoNotSelect;DoNotSave;DoNotChange;ProtectRows;Formula;FormulaValue;ValidationList;SelectionList" type="String"/><column name="EVENT_NAME" property="Validation.Formula2" value="" type="String"/><column name="EVENT_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="EVENT_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="EVENT_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_SCHEMA" property="Address" value="$H$4" type="String"/><column name="HANDLER_SCHEMA" property="ColumnWidth" value="19.71" type="Double"/><column name="HANDLER_SCHEMA" property="NumberFormat" value="General" type="String"/><column name="HANDLER_SCHEMA" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_SCHEMA" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_SCHEMA" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_SCHEMA" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_SCHEMA" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_SCHEMA" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_NAME" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_NAME" property="Address" value="$I$4" type="String"/><column name="HANDLER_NAME" property="ColumnWidth" value="17.57" type="Double"/><column name="HANDLER_NAME" property="NumberFormat" value="General" type="String"/><column name="HANDLER_NAME" property="Validation.Type" value="6" type="Double"/><column name="HANDLER_NAME" property="Validation.Operator" value="8" type="Double"/><column name="HANDLER_NAME" property="Validation.Formula1" value="128" type="String"/><column name="HANDLER_NAME" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_NAME" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="HANDLER_NAME" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="HANDLER_NAME" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_NAME" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_TYPE" property="Address" value="$J$4" type="String"/><column name="HANDLER_TYPE" property="ColumnWidth" value="16.29" type="Double"/><column name="HANDLER_TYPE" property="NumberFormat" value="General" type="String"/><column name="HANDLER_TYPE" property="Validation.Type" value="3" type="Double"/><column name="HANDLER_TYPE" property="Validation.Operator" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.Formula1" value="TABLE;VIEW;PROCEDURE;FUNCTION;CODE;HTTP;TEXT;MACRO;CMD;VALUES;RANGE;REFRESH;MENUSEPARATOR" type="String"/><column name="HANDLER_TYPE" property="Validation.Formula2" value="" type="String"/><column name="HANDLER_TYPE" property="Validation.AlertStyle" value="1" type="Double"/><column name="HANDLER_TYPE" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowInput" value="True" type="Boolean"/><column name="HANDLER_TYPE" property="Validation.ShowError" value="True" type="Boolean"/><column name="HANDLER_CODE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="HANDLER_CODE" property="Address" value="$K$4" type="String"/><column name="HANDLER_CODE" property="ColumnWidth" value="30" type="Double"/><column name="HANDLER_CODE" property="NumberFormat" value="General" type="String"/><column name="TARGET_WORKSHEET" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="TARGET_WORKSHEET" property="Address" value="$L$4" type="String"/><column name="TARGET_WORKSHEET" property="ColumnWidth" value="21.71" type="Double"/><column name="TARGET_WORKSHEET" property="NumberFormat" value="General" type="String"/><column name="TARGET_WORKSHEET" property="Validation.Type" value="6" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Operator" value="8" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.Formula1" value="128" type="String"/><column name="TARGET_WORKSHEET" property="Validation.AlertStyle" value="1" type="Double"/><column name="TARGET_WORKSHEET" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="TARGET_WORKSHEET" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(128) datatype." type="String"/><column name="TARGET_WORKSHEET" property="Validation.ShowInput" value="True" type="Boolean"/><column name="TARGET_WORKSHEET" property="Validation.ShowError" value="True" type="Boolean"/><column name="MENU_ORDER" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="MENU_ORDER" property="Address" value="$M$4" type="String"/><column name="MENU_ORDER" property="ColumnWidth" value="15.43" type="Double"/><column name="MENU_ORDER" property="NumberFormat" value="General" type="String"/><column name="MENU_ORDER" property="Validation.Type" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Operator" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.Formula1" value="-2147483648" type="String"/><column name="MENU_ORDER" property="Validation.Formula2" value="2147483647" type="String"/><column name="MENU_ORDER" property="Validation.AlertStyle" value="1" type="Double"/><column name="MENU_ORDER" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="MENU_ORDER" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String"/><column name="MENU_ORDER" property="Validation.ShowInput" value="True" type="Boolean"/><column name="MENU_ORDER" property="Validation.ShowError" value="True" type="Boolean"/><column name="EDIT_PARAMETERS" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="EDIT_PARAMETERS" property="Address" value="$N$4" type="String"/><column name="EDIT_PARAMETERS" property="ColumnWidth" value="19.57" type="Double"/><column name="EDIT_PARAMETERS" property="NumberFormat" value="General" type="String"/><column name="IS_ACTIVE" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="IS_ACTIVE" property="Address" value="$O$4" type="String"/><column name="IS_ACTIVE" property="ColumnWidth" value="11.43" type="Double"/><column name="IS_ACTIVE" property="NumberFormat" value="General" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$16" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Type" value="2" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Priority" value="14" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.ThemeColor" value="0" type="Double"/><column name="TABLE_SCHEMA" property="FormatConditions(1).Interior.TintAndShade" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/><column name="" property="PageSetup.PaperSize" value="1" type="Double"/></columnFormats></table>', NULL);
INSERT INTO [s11].[formats] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML], [APP]) VALUES (2, N's11', N'Companies', N'<table name="s11.Companies"><columnFormats><column name="" property="ListObjectName" value="Sheet4_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Company" property="Address" value="$C$4" type="String"/><column name="Company" property="ColumnWidth" value="15.57" type="Double"/><column name="Company" property="NumberFormat" value="General" type="String"/><column name="Company" property="Validation.Type" value="6" type="Double"/><column name="Company" property="Validation.Operator" value="8" type="Double"/><column name="Company" property="Validation.Formula1" value="255" type="String"/><column name="Company" property="Validation.AlertStyle" value="1" type="Double"/><column name="Company" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Company" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Company" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="Company" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String"/><column name="Company" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Company" property="Validation.ShowError" value="True" type="Boolean"/><column name="LastModified" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="LastModified" property="Address" value="$D$4" type="String"/><column name="LastModified" property="ColumnWidth" value="14.29" type="Double"/><column name="LastModified" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="LastModified" property="Validation.Type" value="6" type="Double"/><column name="LastModified" property="Validation.Operator" value="8" type="Double"/><column name="LastModified" property="Validation.Formula1" value="255" type="String"/><column name="LastModified" property="Validation.AlertStyle" value="1" type="Double"/><column name="LastModified" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="LastModified" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="LastModified" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="LastModified" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String"/><column name="LastModified" property="Validation.ShowInput" value="True" type="Boolean"/><column name="LastModified" property="Validation.ShowError" value="True" type="Boolean"/><column name="UserName" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="UserName" property="Address" value="$E$4" type="String"/><column name="UserName" property="ColumnWidth" value="12" type="Double"/><column name="UserName" property="NumberFormat" value="General" type="String"/><column name="UserName" property="Validation.Type" value="6" type="Double"/><column name="UserName" property="Validation.Operator" value="8" type="Double"/><column name="UserName" property="Validation.Formula1" value="255" type="String"/><column name="UserName" property="Validation.AlertStyle" value="1" type="Double"/><column name="UserName" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="UserName" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="UserName" property="Validation.ErrorTitle" value="Datatype Control" type="String"/><column name="UserName" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String"/><column name="UserName" property="Validation.ShowInput" value="True" type="Boolean"/><column name="UserName" property="Validation.ShowError" value="True" type="Boolean"/><column name="Company" property="FormatConditions(1).AppliesTo.Address" value="$C$4:$C$11" type="String"/><column name="Company" property="FormatConditions(1).Type" value="2" type="Double"/><column name="Company" property="FormatConditions(1).Priority" value="1" type="Double"/><column name="Company" property="FormatConditions(1).Formula1" value="=ISBLANK(C4)" type="String"/><column name="Company" property="FormatConditions(1).Interior.Color" value="65535" type="Double"/><column name="Company" property="FormatConditions(1).Interior.ThemeColor" value="0" type="Double"/><column name="Company" property="FormatConditions(1).Interior.TintAndShade" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.Zoom" value="100" type="Double"/></columnFormats></table>', NULL);
INSERT INTO [s11].[formats] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [TABLE_EXCEL_FORMAT_XML], [APP]) VALUES (3, N's11', N'Payments', N'<table name="s11.Payments"><columnFormats><column name="" property="ListObjectName" value="Sheet6_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String"/><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean"/><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean"/><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean"/><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="_RowNum" property="Address" value="$B$4" type="String"/><column name="_RowNum" property="NumberFormat" value="General" type="String"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="ID" property="Address" value="$C$4" type="String"/><column name="ID" property="ColumnWidth" value="4.43" type="Double"/><column name="ID" property="NumberFormat" value="General" type="String"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="Address" value="$D$4" type="String"/><column name="Date" property="ColumnWidth" value="10.57" type="Double"/><column name="Date" property="NumberFormat" value="m/d/yyyy" type="String"/><column name="Date" property="BorderxlEdgeRight.LineStyle" value="1" type="Double"/><column name="Date" property="BorderxlEdgeRight.Weight" value="2" type="Double"/><column name="Date" property="BorderxlEdgeRight.Color" value="0" type="Double"/><column name="Date" property="BorderxlEdgeRight.ThemeColor" value="2" type="Double"/><column name="Date" property="BorderxlEdgeRight.TintAndShade" value="0" type="Double"/><column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="Address" value="$E$4" type="String"/><column name="Amount" property="ColumnWidth" value="12.14" type="Double"/><column name="Amount" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 " type="String"/><column name="Amount" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double"/><column name="Amount" property="BorderxlEdgeLeft.Weight" value="2" type="Double"/><column name="Amount" property="BorderxlEdgeLeft.Color" value="0" type="Double"/><column name="Amount" property="BorderxlEdgeLeft.ThemeColor" value="2" type="Double"/><column name="Amount" property="BorderxlEdgeLeft.TintAndShade" value="0" type="Double"/><column name="Amount" property="BorderxlEdgeRight.LineStyle" value="1" type="Double"/><column name="Amount" property="BorderxlEdgeRight.Weight" value="2" type="Double"/><column name="Amount" property="BorderxlEdgeRight.Color" value="0" type="Double"/><column name="Amount" property="BorderxlEdgeRight.ThemeColor" value="2" type="Double"/><column name="Amount" property="BorderxlEdgeRight.TintAndShade" value="0" type="Double"/><column name="Account" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Account" property="Address" value="$F$4" type="String"/><column name="Account" property="ColumnWidth" value="10" type="Double"/><column name="Account" property="NumberFormat" value="General" type="String"/><column name="Account" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double"/><column name="Account" property="BorderxlEdgeLeft.Weight" value="2" type="Double"/><column name="Account" property="BorderxlEdgeLeft.Color" value="0" type="Double"/><column name="Account" property="BorderxlEdgeLeft.ThemeColor" value="2" type="Double"/><column name="Account" property="BorderxlEdgeLeft.TintAndShade" value="0" type="Double"/><column name="Account" property="BorderxlEdgeRight.LineStyle" value="1" type="Double"/><column name="Account" property="BorderxlEdgeRight.Weight" value="2" type="Double"/><column name="Account" property="BorderxlEdgeRight.Color" value="0" type="Double"/><column name="Account" property="BorderxlEdgeRight.ThemeColor" value="2" type="Double"/><column name="Account" property="BorderxlEdgeRight.TintAndShade" value="0" type="Double"/><column name="Account" property="Validation.Type" value="3" type="Double"/><column name="Account" property="Validation.Operator" value="1" type="Double"/><column name="Account" property="Validation.Formula1" value="Bank" type="String"/><column name="Account" property="Validation.Formula2" value="" type="String"/><column name="Account" property="Validation.AlertStyle" value="1" type="Double"/><column name="Account" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Account" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Account" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Account" property="Validation.ShowError" value="True" type="Boolean"/><column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Company" property="Address" value="$G$4" type="String"/><column name="Company" property="ColumnWidth" value="15.71" type="Double"/><column name="Company" property="NumberFormat" value="General" type="String"/><column name="Company" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double"/><column name="Company" property="BorderxlEdgeLeft.Weight" value="2" type="Double"/><column name="Company" property="BorderxlEdgeLeft.Color" value="0" type="Double"/><column name="Company" property="BorderxlEdgeLeft.ThemeColor" value="2" type="Double"/><column name="Company" property="BorderxlEdgeLeft.TintAndShade" value="0" type="Double"/><column name="Company" property="BorderxlEdgeRight.LineStyle" value="1" type="Double"/><column name="Company" property="BorderxlEdgeRight.Weight" value="2" type="Double"/><column name="Company" property="BorderxlEdgeRight.Color" value="0" type="Double"/><column name="Company" property="BorderxlEdgeRight.ThemeColor" value="2" type="Double"/><column name="Company" property="BorderxlEdgeRight.TintAndShade" value="0" type="Double"/><column name="Company" property="Validation.Type" value="3" type="Double"/><column name="Company" property="Validation.Operator" value="1" type="Double"/><column name="Company" property="Validation.Formula1" value="=INDIRECT(&quot;vl_s11_Companies[Company]&quot;)" type="String"/><column name="Company" property="Validation.Formula2" value="" type="String"/><column name="Company" property="Validation.AlertStyle" value="1" type="Double"/><column name="Company" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Company" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Company" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Company" property="Validation.ShowError" value="True" type="Boolean"/><column name="Item" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Item" property="Address" value="$H$4" type="String"/><column name="Item" property="ColumnWidth" value="11.43" type="Double"/><column name="Item" property="NumberFormat" value="General" type="String"/><column name="Item" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double"/><column name="Item" property="BorderxlEdgeLeft.Weight" value="2" type="Double"/><column name="Item" property="BorderxlEdgeLeft.Color" value="0" type="Double"/><column name="Item" property="BorderxlEdgeLeft.ThemeColor" value="2" type="Double"/><column name="Item" property="BorderxlEdgeLeft.TintAndShade" value="0" type="Double"/><column name="Item" property="BorderxlEdgeRight.LineStyle" value="1" type="Double"/><column name="Item" property="BorderxlEdgeRight.Weight" value="2" type="Double"/><column name="Item" property="BorderxlEdgeRight.Color" value="0" type="Double"/><column name="Item" property="BorderxlEdgeRight.ThemeColor" value="2" type="Double"/><column name="Item" property="BorderxlEdgeRight.TintAndShade" value="0" type="Double"/><column name="Item" property="Validation.Type" value="3" type="Double"/><column name="Item" property="Validation.Operator" value="1" type="Double"/><column name="Item" property="Validation.Formula1" value="Revenue;Expenses;Payroll;Taxes" type="String"/><column name="Item" property="Validation.Formula2" value="" type="String"/><column name="Item" property="Validation.AlertStyle" value="1" type="Double"/><column name="Item" property="Validation.IgnoreBlank" value="True" type="Boolean"/><column name="Item" property="Validation.InCellDropdown" value="True" type="Boolean"/><column name="Item" property="Validation.ShowInput" value="True" type="Boolean"/><column name="Item" property="Validation.ShowError" value="True" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="Address" value="$I$4" type="String"/><column name="Comment" property="ColumnWidth" value="11.29" type="Double"/><column name="Comment" property="NumberFormat" value="General" type="String"/><column name="Comment" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double"/><column name="Comment" property="BorderxlEdgeLeft.Weight" value="2" type="Double"/><column name="Comment" property="BorderxlEdgeLeft.Color" value="0" type="Double"/><column name="Comment" property="BorderxlEdgeLeft.ThemeColor" value="2" type="Double"/><column name="Comment" property="BorderxlEdgeLeft.TintAndShade" value="0" type="Double"/><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean"/><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean"/><column name="" property="ActiveWindow.Split" value="True" type="Boolean"/><column name="" property="ActiveWindow.SplitRow" value="0" type="Double"/><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double"/><column name="" property="PageSetup.Orientation" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double"/><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double"/><column name="" property="PageSetup.PaperSize" value="1" type="Double"/></columnFormats><views><view name="All Payments"><column name="" property="ListObjectName" value="Sheet6_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Account" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Item" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/></view><view name="Incomes"><column name="" property="ListObjectName" value="Sheet6_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Account" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Item" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="AutoFilter.Criteria1" value="&gt;0" type="String"/></view><view name="Expenses"><column name="" property="ListObjectName" value="Sheet6_Table1" type="String"/><column name="" property="ShowTotals" value="False" type="Boolean"/><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean"/><column name="ID" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Date" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Account" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Company" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Item" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Comment" property="EntireColumn.Hidden" value="False" type="Boolean"/><column name="Amount" property="AutoFilter.Criteria1" value="&lt;0" type="String"/></view></views></table>', NULL);
SET IDENTITY_INSERT [s11].[formats] OFF;
GO

SET IDENTITY_INSERT [s11].[handlers] ON;
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (1, N's11', N'handlers', N'HANDLER_CODE', N'DoNotConvertFormulas', NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (2, N's11', N'handlers', N'EVENT_NAME', N'ValidationList', NULL, NULL, N'VALUES', N'Actions, Change, ContextMenu, DoubleClick, SelectionChange, ConvertFormulas, DoNotConvertFormulas, DoNotSelect, DoNotSave, DoNotChange, DoNotAddValidation, DoNotAddChangeHandler, ProtectRows, Formula, FormulaValue, ParameterValues, ValidationList, SelectionList, SyncParameter, DefaultListObject, ManyToMany, DoNotAddManyToMany, AddStateColumn, KeepFormulas, DoNotKeepFormulas, UpdateEntireRow, UpdateChangedCellsOnly', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (3, N's11', N'handlers', N'HANDLER_TYPE', N'ValidationList', NULL, NULL, N'VALUES', N'TABLE, VIEW, PROCEDURE, FUNCTION, CODE, HTTP, TEXT, MACRO, CMD, VALUES, RANGE, REFRESH, MENUSEPARATOR, PDF, REPORT, SHOWSHEETS, HIDESHEETS, SELECTSHEET', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (4, N's11', N'handlers', NULL, N'Actions', N's11', N'SaveToDB Online Help', N'HTTP', N'https://www.savetodb.com/savetodb/configuring-event-handlers.htm', NULL, 11, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (5, N's11', N'handlers', NULL, N'Actions', N's11', N'SaveToDB Framework Online Help', N'HTTP', N'https://www.savetodb.com/help/savetodb-framework-tables.htm#xls.handlers', NULL, 12, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (6, N's11', N'Payments', N'Account', N'ValidationList', N's11', N'Accounts', N'VALUES', N'Bank', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (7, N's11', N'Payments', N'Item', N'ValidationList', N's11', N'Items', N'VALUES', N'Revenue,Expenses,Payroll,Taxes', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (8, N's11', N'Payments', N'Company', N'ValidationList', N's11', N'Companies', N'TABLE', N'Company', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (9, N's11', N'Payments', NULL, N'SelectionChange', N's11', N'Payments', N'TABLE', NULL, N'_TaskPane _Transpose', NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (10, N's11', N'Payments', N'Company', N'ContextMenu', N's11', N'Payments', N'TABLE', N'+Date,+Amount,Account,@Company,Item,Comment', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (11, N's11', N'Payments', N'Item', N'ContextMenu', N's11', N'Payments', N'TABLE', N'+Date,+Amount,Account,Company,@Item,Comment', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (12, N's11', N'Companies', N'LastModified', N'FormulaValue', NULL, NULL, NULL, N'=NOW()', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (13, N's11', N'Companies', N'UserName', N'FormulaValue', NULL, NULL, NULL, N'=UserName()', NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (14, N's11', N'Companies', N'LastModified', N'DoNotChange', NULL, NULL, NULL, NULL, NULL, NULL, NULL);
INSERT INTO [s11].[handlers] ([ID], [TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME], [HANDLER_TYPE], [HANDLER_CODE], [TARGET_WORKSHEET], [MENU_ORDER], [EDIT_PARAMETERS]) VALUES (15, N's11', N'Companies', N'UserName', N'DoNotChange', NULL, NULL, NULL, NULL, NULL, NULL, NULL);
SET IDENTITY_INSERT [s11].[handlers] OFF;
GO

SET IDENTITY_INSERT [s11].[Payments] ON;
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (1, '20230110 00:00:00.000', 200000, N'Bank', N'Revenue', N'Customer C1', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (2, '20230110 00:00:00.000', -50000, N'Bank', N'Expenses', N'Supplier S1', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (3, '20230131 00:00:00.000', -85000, N'Bank', N'Payroll', NULL, NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (4, '20230131 00:00:00.000', -15000, N'Bank', N'Taxes', N'Individual Income Tax', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (5, '20230131 00:00:00.000', -15000, N'Bank', N'Taxes', N'Payroll Taxes', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (6, '20230210 00:00:00.000', 300000, N'Bank', N'Revenue', N'Customer C1', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (7, '20230210 00:00:00.000', 100000, N'Bank', N'Revenue', N'Customer C2', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (8, '20230210 00:00:00.000', -50000, N'Bank', N'Expenses', N'Supplier S2', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (9, '20230210 00:00:00.000', -100000, N'Bank', N'Expenses', N'Supplier S1', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (10, '20230228 00:00:00.000', -85000, N'Bank', N'Payroll', NULL, NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (11, '20230228 00:00:00.000', -15000, N'Bank', N'Taxes', N'Individual Income Tax', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (12, '20230228 00:00:00.000', -15000, N'Bank', N'Taxes', N'Payroll Taxes', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (13, '20230310 00:00:00.000', 300000, N'Bank', N'Revenue', N'Customer C1', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (14, '20230310 00:00:00.000', 200000, N'Bank', N'Revenue', N'Customer C2', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (15, '20230310 00:00:00.000', 100000, N'Bank', N'Revenue', N'Customer C3', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (16, '20230315 00:00:00.000', -100000, N'Bank', N'Taxes', N'Corporate Income Tax', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (17, '20230331 00:00:00.000', -170000, N'Bank', N'Payroll', NULL, NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (18, '20230331 00:00:00.000', -30000, N'Bank', N'Taxes', N'Individual Income Tax', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (19, '20230331 00:00:00.000', -30000, N'Bank', N'Taxes', N'Payroll Taxes', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (20, '20230331 00:00:00.000', -50000, N'Bank', N'Expenses', N'Supplier S2', NULL);
INSERT INTO [s11].[Payments] ([ID], [Date], [Amount], [Account], [Item], [Company], [Comment]) VALUES (21, '20230331 00:00:00.000', -100000, N'Bank', N'Expenses', N'Supplier S1', NULL);
SET IDENTITY_INSERT [s11].[Payments] OFF;
GO

CREATE ROLE sample11_Alex_Team;
GO

GRANT SELECT, INSERT, UPDATE, DELETE, EXECUTE, VIEW DEFINITION ON SCHEMA::s11 TO sample11_Alex_Team;
GO

print 'Application installed';
